server_verify_final

Function server_verify_final 

pub fn server_verify_final(
    handshake: &ScramHandshake,
    client_final_b64: &str,
) -> Result<Vec<u8>, AuthError>
Server-side: Verify client-final-message and produce server signature.

Decodes the client-final-message, verifies the client proof against the stored key in the handshake state, and returns the server signature for the client to verify (sent as the v= field in server-final-message).