Skip to main contentModule zinc
Source - ZincCodec
- Zinc wire format codec.
- ZincParser
- Hand-written recursive descent parser for Zinc wire format.
- decode_grid
- Decode a Zinc-formatted string into an HGrid.
- decode_scalar
- Decode a single Zinc scalar value from a string.
- encode_grid
- Encode an HGrid to the Zinc wire format.
- encode_meta
- Encode metadata tags in inline format for grid/column metadata.
Format:
"tag1 tag2:val2 tag3:val3" - encode_scalar
- Encode a single Kind value to its Zinc string representation.
- escape_str
- Escape string content for Zinc format (without outer quotes).