pub fn encode_scalar(val: &Kind) -> Result<String, CodecError>Expand description
Encode a single Kind value to its Zinc string representation.
pub fn encode_scalar(val: &Kind) -> Result<String, CodecError>Encode a single Kind value to its Zinc string representation.