Module data

Module data 

Haystack data collection types.

  • HDict — Tag dictionary (ordered map of name → Kind value). Represents a single entity, grid metadata, or column metadata.
  • HGrid — Two-dimensional table of HCol columns and HDict rows. The primary data exchange format in the Haystack protocol.
  • HCol — Named column with optional metadata dict.
  • HList — Ordered list of Kind values.

Structs

HCol
A single column in a Haystack Grid.
HDict
Haystack Dict — the fundamental entity/row type in Haystack.
HGrid
Haystack Grid — the fundamental tabular data structure.
HList
Haystack List — a thin wrapper around Vec<Kind>.