Module entity_graph

Module entity_graph 

Structs

EntityGraph
Core entity graph with bitmap tag indexing and bidirectional ref adjacency.
HierarchyNode
A node in a hierarchy tree produced by EntityGraph::hierarchy_tree.

Enums

GraphError
Errors returned by EntityGraph operations.