Module query_planner

Module query_planner 

Functions

bitmap_candidates
Compute a bitmap of candidate entity ids that may match the given filter node, using tag presence bitmaps only.
bitmap_candidates_with_values
Enhanced candidate computation that uses B-Tree value indexes and ref adjacency for Cmp nodes in addition to tag bitmap indexes.