Module fitting

Module fitting 

Functions

fits
Check whether an entity structurally fits a Xeto spec.
fits_explain
Explain why an entity does or does not fit a Xeto spec.

Type Aliases

EntityResolver
Entity resolver function type for query evaluation. Given a ref, returns the entity dict if it exists.