Haystack data collection types.
HDict— Tag dictionary (ordered map of name →Kindvalue). Represents a single entity, grid metadata, or column metadata.HGrid— Two-dimensional table ofHColcolumns andHDictrows. The primary data exchange format in the Haystack protocol.HCol— Named column with optional metadata dict.HList— Ordered list ofKindvalues.