ValueIndex

Struct ValueIndex 

pub struct ValueIndex { /* private fields */ }
A collection of B-Tree indexes keyed by field name.

Each index maps orderable values to the set of entity IDs that have that value for the given field. Supports efficient range lookups.

Implementations

Source

impl ValueIndex

pub fn new() -> Self

Create an empty value index.

pub fn index_field(&mut self, field: &str)

Register a field for indexing. Call this before adding entities.

pub fn indexed_fields(&self) -> impl Iterator<Item = &str>

Returns the set of indexed field names.

pub fn has_index(&self, field: &str) -> bool

Returns true if a given field has a value index.

pub fn add(&mut self, entity_id: usize, field: &str, value: &Kind)

Add an entity’s value to the index for a given field.

pub fn remove(&mut self, entity_id: usize, field: &str, value: &Kind)

Remove an entity from the index for a given field/value.

pub fn eq_lookup(&self, field: &str, val: &Kind) -> Vec<usize>

Look up entity IDs where field == val.

pub fn ne_lookup(&self, field: &str, val: &Kind) -> Vec<usize>

Look up entity IDs where field != val (all indexed minus exact match).

pub fn gt_lookup(&self, field: &str, val: &Kind) -> Vec<usize>

Look up entity IDs where field > val.

pub fn ge_lookup(&self, field: &str, val: &Kind) -> Vec<usize>

Look up entity IDs where field >= val.

pub fn lt_lookup(&self, field: &str, val: &Kind) -> Vec<usize>

Look up entity IDs where field < val.

pub fn le_lookup(&self, field: &str, val: &Kind) -> Vec<usize>

Look up entity IDs where field <= val.

pub fn clear(&mut self)

Clear all indexes.