pub struct Lib {
pub name: String,
pub version: String,
pub doc: String,
pub depends: Vec<String>,
pub defs: HashMap<String, Def>,
}Expand description
A library of Haystack 4 definitions.
Each library groups related defs under a name (e.g. "phIoT") and
tracks its version, documentation, and dependencies on other libraries.
Fields
name: StringLibrary name, e.g. "phIoT".
version: StringVersion string, e.g. "4.0.0".
doc: StringLibrary description.
depends: Vec<String>Names of dependent libraries.
defs: HashMap<String, Def>Symbol -> Def mapping.
Implementations