Functions
- fits
- Check whether an entity structurally fits a Xeto spec.
- fits_
explain - Explain why an entity does or does not fit a Xeto spec.
Type Aliases
- Entity
Resolver - Entity resolver function type for query evaluation. Given a ref, returns the entity dict if it exists.